# Generated by Django 2.1.1 on 2018-09-21 00:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('rc_django', '0003_auto_20170504_2136'),
    ]

    operations = [
        migrations.RenameField(
            model_name='cacheentry',
            old_name='header_pickle',
            new_name='headers',
        ),
    ]
