<h1>Course Section Search (Proxy)</h1>
<form method="get" action="section.json">
{% include 'proxy/sws/student/v5/includes/term.html' %}
{% include 'proxy/sws/student/v5/includes/course.html' %}
{% include 'proxy/sws/student/v5/includes/reg_id.html' %}
<div><label for="facility_code">Facility Code:</label> <input class="facility_code" id="facility_code" name="facility_code" value="{{search.facility_code}}" type="text" size="8">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
<label for="room_number">Room Number:</label> <input class="room_number" id="room_number" name="room_number" value="{{search.room_number}}" type="text" size="3"></div>
<div>
    <input class="search_by" id="search_by_instructor" name="search_by" value="Instructor"{% if search.search_by == "Instructor" %} checked="checked"{% endif %} type="radio">
<label for="search_by_instructor">Instructor</label>
<input class="search_by" id="search_by_delegate" name="search_by" value="GradeSubmissionDelegate"{% if search.search_by == "GradeSubmissionDelegate" %} checked="checked"{% endif %} type="radio">
<label for="search_by_delegate">Grade Submission Delegate</label>
</div>
<div><label for="include_secondaries">Include secondary sections:</label> <input class="include_secondaries" id="include_secondaries" name="include_secondaries" value="on"{% if search.include_secondaries == "on" %} checked="checked"{% endif %} type="checkbox"></div>
<div><label for="delete_flag">Delete flag:</label> <input class="delete_flag" id="delete_flag" name="delete_flag" value="{{search.delete_flag}}" size="15" type="text"></div>
{% include 'proxy/sws/student/v5/includes/transcriptable_course.html' %}
{% include 'proxy/sws/student/v5/includes/changed_since_date.html' %}
{% include 'proxy/sws/student/v5/includes/page_size.html' %}
<input value="Search" type="submit">                                            
</form>
