<h1>Curriculum Search (Proxy)</h1>
<form method="get" action="curriculum.json">
{% include 'proxy/sws/student/v5/includes/term.html' %}
{% include 'proxy/sws/student/v5/includes/department_abbreviation.html' %}
{% include 'proxy/sws/student/v5/includes/college_abbreviation.html' %}
{% include 'proxy/sws/student/v5/includes/view_unpublished.html' %}
{% include 'proxy/sws/student/v5/includes/page_size.html' %}
<input value="Search" type="submit">
</form>
