<div><label for="year">Year:</label> <input class="year" id="year" name="year" value="{{search.year}}" type="text" size="4">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
<label for="quarter">Quarter:</label> <select class="quarter" id="quarter" name="quarter"><option value="">select...</option><option value="summer"{% if search.quarter == 'summer' %} selected="selected"{% endif %}>summer</option><option value="autumn"{% if search.quarter == 'autumn' %} selected="selected"{% endif %}>autumn</option><option value="winter"{% if search.quarter == 'winter' %} selected="selected"{% endif %}>winter</option><option value="spring"{% if search.quarter == 'spring' %} selected="selected"{% endif %}>spring</option></select>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
<label for="future_terms">Number of future terms to search:</label>
<input class="future_terms" id="future_terms" name="future_terms" value="{{search.future_terms}}" type="number" min="0" max="100">
</div>
